==> jettable1.0.0.zip: jettable/sample/client_hotmail.php <==
<?php
require_once "../TableUtility.php";

$list = array();



$list[] = array("icon"=>"<IMG class=KK alt=ʺп src=\"http://gfx1.hotmail.com/i.F42B5.gif\">", "attach"=>"", "check"=>"<INPUT type=checkbox>", "п"=>"FC2 Information", "̾"=>"FC2ΤΤ餻", ""=>"118", ""=>"3KB");
$list[] = array("icon"=>"<IMG class=KK alt=ʺп src=\"http://gfx1.hotmail.com/i.F42B5.gif\">", "check"=>"<INPUT type=checkbox>", "п"=>"FC2 Information", "̾"=>"FC2ΤΤ餻", ""=>"118", ""=>"3KB");
$list[] = array("icon"=>"<IMG height=11 alt=᡼ hspace=5 src=\"http://gfx1.hotmail.com/i.p.new.gif\" width=14 border=0>", "check"=>"<INPUT type=checkbox>", "п"=>"FC2֥", "̾"=>"λΤΤ餻", ""=>"116", ""=>"3KB");
$list[] = array("icon"=>"<IMG class=KK alt=ʺп src=\"http://gfx1.hotmail.com/i.F424A.gif\">", "check"=>"<INPUT type=checkbox>", "п"=>"fc2@fc2.com", "̾"=>"FC2ID ϿλΤΤ餻", ""=>"116", ""=>"2KB");
$list[] = array("icon"=>"<IMG height=11 alt=᡼ hspace=5 src=\"http://gfx1.hotmail.com/i.p.new.gif\" width=14 border=0>", "check"=>"<INPUT type=checkbox>", "п"=>"fc2@fc2.com", "̾"=>"FC2ID Ͽѥ᡼", ""=>"116", ""=>"2KB");
$list[] = array("icon"=>"<IMG class=KK alt=\"MSN Υ᡼\" src=\"http://gfx1.hotmail.com/i.1EF9B0.gif\">", "check"=>"<INPUT type=checkbox>", "п"=>"Hotmail С ...", "̾"=>"MSN Hotmail ؤ褦", ""=>"116", ""=>"1KB");


$table = new Table();
$table->setData($list);

$table->setHeader(array(
	"icon"=>"<IMG height=11 alt=᡼ hspace=5 src=\"http://gfx1.hotmail.com/i.p.new.gif\" width=14 border=0>", 
	"attach"=>"<IMG alt=źեե src=\"http://gfx1.hotmail.com/i.p.attach.gif\" border=0>", 
	"check"=>"<INPUT type=checkbox>",
	"п"=>"п",
	"̾"=>"̾",
	""=>"",
	""=>"",
));


$table->appendAttribute("border", "0");
$table->appendAttribute("cellpadding", "0");
$table->appendAttribute("cellspacing", "0");
$table->appendAttribute("width", "100%");

$table->appendAttributeHeaderRow("bgcolor", "#dbeaf5");
$table->appendAttributeHeaderRow("style", "color:#00f;text-decoration:underline;");

$table->appendAttributeHeaderColumn("icon", "align", "middle");
$table->appendAttributeHeaderColumn("icon", "width", "25");
$table->appendAttributeHeaderColumn("attach", "width", "25");
$table->appendAttributeHeaderColumn("check", "width", "25");
$table->appendAttributeHeaderColumn("п", "height", "24");
$table->appendAttributeHeaderColumn("п", "width", "60");
$table->appendAttributeHeaderColumn("п", "style", "font-weight:normal;cursor:pointer;");
$table->appendAttributeHeaderColumn("̾", "width", "100");
$table->appendAttributeHeaderColumn("̾", "style", "font-weight:normal;cursor:pointer;");
$table->appendAttributeHeaderColumn("", "width", "50");
$table->appendAttributeHeaderColumn("", "style", "font-weight:normal;cursor:pointer;");
$table->appendAttributeHeaderColumn("", "align", "right");
$table->appendAttributeHeaderColumn("", "style", "font-weight:normal;cursor:pointer;");

$table->appendAttributeRow("bgcolor", "#fff7e5");

$table->appendAttributeColumn("icon", "align", "middle");
$table->appendAttributeColumn("", "align", "right");
$table->appendAttributeColumn("п", "style", "color:#00f;text-decoration:underline;font-weight:normal;cursor:pointer;");

print<<<HEADER
<html>
<head>
<style type="text/css">
<!--
-->
</style>
</head>
<body>
HEADER;

print $table->getTableHtml();

print<<<FOOTER
</body>
</html>
FOOTER;
?>

==> jettable2.0.0.zip: jettable/sample/client_hotmail.php <==
<?php
require_once "../JetTable.php";

$list = array();



$list[] = array("icon"=>"<IMG class=KK alt=ʺп src=\"http://gfx1.hotmail.com/i.F42B5.gif\">", "attach"=>"", "check"=>"<INPUT type=checkbox>", "п"=>"FC2 Information", "̾"=>"FC2ΤΤ餻", ""=>"118", ""=>"3KB");
$list[] = array("icon"=>"<IMG class=KK alt=ʺп src=\"http://gfx1.hotmail.com/i.F42B5.gif\">", "check"=>"<INPUT type=checkbox>", "п"=>"FC2 Information", "̾"=>"FC2ΤΤ餻", ""=>"118", ""=>"3KB");
$list[] = array("icon"=>"<IMG height=11 alt=᡼ hspace=5 src=\"http://gfx1.hotmail.com/i.p.new.gif\" width=14 border=0>", "check"=>"<INPUT type=checkbox>", "п"=>"FC2֥", "̾"=>"λΤΤ餻", ""=>"116", ""=>"3KB");
$list[] = array("icon"=>"<IMG class=KK alt=ʺп src=\"http://gfx1.hotmail.com/i.F424A.gif\">", "check"=>"<INPUT type=checkbox>", "п"=>"fc2@fc2.com", "̾"=>"FC2ID ϿλΤΤ餻", ""=>"116", ""=>"2KB");
$list[] = array("icon"=>"<IMG height=11 alt=᡼ hspace=5 src=\"http://gfx1.hotmail.com/i.p.new.gif\" width=14 border=0>", "check"=>"<INPUT type=checkbox>", "п"=>"fc2@fc2.com", "̾"=>"FC2ID Ͽѥ᡼", ""=>"116", ""=>"2KB");
$list[] = array("icon"=>"<IMG class=KK alt=\"MSN Υ᡼\" src=\"http://gfx1.hotmail.com/i.1EF9B0.gif\">", "check"=>"<INPUT type=checkbox>", "п"=>"Hotmail С ...", "̾"=>"MSN Hotmail ؤ褦", ""=>"116", ""=>"1KB");


$table = new JetTable();
$table->setData($list);

$table->setHeader(array(
	"icon"=>"<IMG height=11 alt=᡼ hspace=5 src=\"http://gfx1.hotmail.com/i.p.new.gif\" width=14 border=0>", 
	"attach"=>"<IMG alt=źեե src=\"http://gfx1.hotmail.com/i.p.attach.gif\" border=0>", 
	"check"=>"<INPUT type=checkbox>",
	"п"=>"п",
	"̾"=>"̾",
	""=>"",
	""=>"",
));


$table->appendAttribute("border", "0");
$table->appendAttribute("cellpadding", "0");
$table->appendAttribute("cellspacing", "0");
$table->appendAttribute("width", "100%");

$table->appendAttributeHeaderRow("bgcolor", "#dbeaf5");
$table->appendAttributeHeaderRow("style", "color:#00f;text-decoration:underline;");

$table->appendAttributeHeaderColumn("icon", "align", "middle");
$table->appendAttributeHeaderColumn("icon", "width", "25");
$table->appendAttributeHeaderColumn("attach", "width", "25");
$table->appendAttributeHeaderColumn("check", "width", "25");
$table->appendAttributeHeaderColumn("п", "height", "24");
$table->appendAttributeHeaderColumn("п", "width", "60");
$table->appendAttributeHeaderColumn("п", "style", "font-weight:normal;cursor:pointer;");
$table->appendAttributeHeaderColumn("̾", "width", "100");
$table->appendAttributeHeaderColumn("̾", "style", "font-weight:normal;cursor:pointer;");
$table->appendAttributeHeaderColumn("", "width", "50");
$table->appendAttributeHeaderColumn("", "style", "font-weight:normal;cursor:pointer;");
$table->appendAttributeHeaderColumn("", "align", "right");
$table->appendAttributeHeaderColumn("", "style", "font-weight:normal;cursor:pointer;");

$table->appendAttributeRow("bgcolor", "#fff7e5");

$table->appendAttributeColumn("icon", "align", "middle");
$table->appendAttributeColumn("", "align", "right");
$table->appendAttributeColumn("п", "style", "color:#00f;text-decoration:underline;font-weight:normal;cursor:pointer;");

print<<<HEADER
<html>
<head>
<style type="text/css">
<!--
-->
</style>
</head>
<body>
HEADER;

print $table->getTableHtml();

print<<<FOOTER
</body>
</html>
FOOTER;
?>
